/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.server.persistence.impl;

import org.ogf.graap.wsag.api.Agreement;
import org.ogf.graap.wsag.server.persistence.PersistentAgreement;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

/**
 * Default implementation of a persistent agreement. Essentially this agreement is not persisted at all. It
 * implements the {@link PersistentAgreement} interface and is superseded by the
 * {@link DatabasePersistentAgreement}.
 * 
 * @author Oliver Waeldrich
 * 
 */
public class SimplePersistentAgreement implements PersistentAgreement
{

    private Agreement agreement;

    private EndpointReferenceType epr;

    /**
     * 
     * @param agreement
     *            the agreement instance
     * 
     * @param epr
     *            the agreement EPR
     */
    public SimplePersistentAgreement( Agreement agreement, EndpointReferenceType epr )
    {
        this.agreement = agreement;
        this.epr = epr;
    }

    /**
     * {@inheritDoc}
     */
    public Agreement getAgreement()
    {
        return agreement;
    }

    /**
     * {@inheritDoc}
     */
    public EndpointReferenceType getAgreementEPR()
    {
        return epr;
    }

    /**
     * {@inheritDoc}
     */
    public void load() throws Exception
    {
        //
        // nothing to do in simple implementation
        //
    }

    /**
     * {@inheritDoc}
     */
    public void save() throws Exception
    {
        //
        // nothing to do in simple implementation
        //
    }

}
